#
# This is a Shiny web application. You can run the application by clicking
# the 'Run App' button above.
#
# Find out more about building applications with Shiny here:
#
#    http://shiny.rstudio.com/
#


##  Introduction to reactivity:

##  Notice that so far, everything we did just worked, without thinking too hard about it.  But
##  we need to think about how R knew to update the graphic when things were changed in the interface.
##  Does any change to the input redo the output?  If so, that would be unfortunate.
##  As it currently stands, there is code within shiny that figures out the dependencies
##  between the input and the output. For example, when n was fixed to 1000 in the previous example,
## and the sample selection was not hooked up, it didn't re-run the figure on each update!

## But sometimes, we want the update of the interface to react to some changes but not others. For 
## example, right now, the app doesn't know that the bins argument is just 'for display'.  Let's
## try to make changes in the bins argument NOT resample the data. Do the following:
##
## Instructions:
##  * Get rid of the qqplot and grid.arrange so the plotOutput has just one plot.
##  * Put a histogram of the second distribution in a second plotOutput  (maybe named disPlot2),
##    moving the generation vals into the  plotting function in the server.
## * Add a second numeric input to control the samples in the second output histogram.
## * Determine whether everything gets updated or the two independent graphics update
## * independently.

##Once complete, verify that the distribution only gets resampled when samples or distribution is changed for that particular graph.
## Finally, look at what happens when you change the bins argument. Does the data get resampled then?

library(shiny)
library(ggplot2)
library(gridExtra)


# Define UI for application that draws a histogram
ui <- fluidPage(
  
  # Application title
  titlePanel("Random distribution generation"),
  
  # Sidebar with a slider input for number of bins 
  sidebarLayout(
    sidebarPanel(
      sliderInput("bins",                        "Number of bins:",
                  min = 1,
                  max = 50,
                  value = 30),
      selectInput("type",label="Select form of distribution",
                  choices=c("normal","uniform")),
      numericInput("number","Number of samples",500,min=100,max=10000,step=100,width='100%'),
      
      
      tags$a("Link to wikipedia",href="http://en.wikipedia.org"),
      tags$p(),
      tags$hr(),
      tags$a( tags$img(src="https://upload.wikimedia.org/wikipedia/en/c/c9/Michigan_Technological_University_logo.svg"),
              href="http://mtu.edu")
    ),
    
    # Show a plot of the generated distribution
    mainPanel(
      h1("Histogram and normal q-q plot"),
      plotOutput("distPlot")
    )
  )
)



# Define server logic required to draw a histogram
server <- function(input, output) {
  
  
  
  output$distPlot <- renderPlot({
    n <- input$number
    
    if(input$type=="uniform")
    {
      x    <- runif(n)
    } else if(input$type=="normal")
    {
      x    <-  rnorm(n)
    } else{
      x <- 1:n
    }
    
    # draw the histogram with the specified number of bins
    a <- as.data.frame(x) |> ggplot(aes(x=x)) +geom_histogram(bins=input$bins,fill="orange2",color="black") + theme_bw()
    b <- as.data.frame(x) |> ggplot(aes(sample=x)) + geom_qq() + theme_bw()
    grid.arrange(a,b,ncol=2)
    
  })
}
# Run the application 
shinyApp(ui = ui, server = server)
