#
# This is a Shiny web application. You can run the application by clicking
# the 'Run App' button above.
#
# Find out more about building applications with Shiny here:
#
#    http://shiny.rstudio.com/
#


## Here, the second plot accesses the reactive data, which only get regenerated when input$type or input$number
## changes. When bins change, this does not require data to be remade.      
## But changing n and type DOES require the first data set to be resampled, because it is within the 
## plotting function.

library(shiny)
library(ggplot2)

# Define UI for application that draws a histogram
ui <- fluidPage(

  
  # Application title
  titlePanel("Random distribution generation"),
  
  # Sidebar with a slider input for number of bins 
  sidebarLayout(
    sidebarPanel(
      sliderInput("bins",                        "Number of bins:",
                  min = 1,
                  max = 50,
                  value = 30),
      selectInput("type",label="Select form of distribution",
                  choices=c("normal","uniform")),
      numericInput("number","Number of samples",500,min=100,max=10000,step=100,width='100%'),
      
      
      tags$a("Link to wikipedia",href="http://en.wikipedia.org"),
      tags$p(),
      tags$hr(),
      tags$a( tags$img(src="https://upload.wikimedia.org/wikipedia/en/c/c9/Michigan_Technological_University_logo.svg"),
              href="http://mtu.edu")
    ),
    
    # Show a plot of the generated distribution
    mainPanel(
      h1("Histograms"),
      plotOutput("distPlot",width=350,height=300),
      plotOutput("distPlot2",width=350, height=300)
    )
  )
)



# Define server logic required to draw a histogram
server <- function(input, output) {

     ##put reactive data element here:
      data <- reactive(
        {
          if( input$type=="normal")
          {
            x    <-  rnorm(input$number)  
          }else if(input$type=="uniform")
          {
            x    <-  runif(input$number)  
          }
            x
        }
    )
      
  
      output$distPlot <- renderPlot({
        n <- input$number
        
        if(input$type=="uniform")
        {
          x    <- runif(n)
        } else if(input$type=="normal")
        {
          x    <-  rnorm(n)
        } else{
          x <- 1:n
        }
        
        # draw the histogram with the specified number of bins
        a <- as.data.frame(x) |> ggplot(aes(x=x)) +geom_histogram(bins=input$bins,fill="orange2",color="black") + theme_bw()
        print(a)
      })
      
      
      output$distPlot2 <- renderPlot({
        x <- data()
        # draw the histogram with the specified number of bins
        a <- as.data.frame(x) |> ggplot(aes(x=x)) +geom_histogram(bins=input$bins,fill="navy",color="black") + theme_bw()
        print(a)
      })
      
      
      
}

# Run the application 
shinyApp(ui = ui, server = server)
